/*
  Copyright (C) 2013 Jolla Ltd.
  Contact: Thomas Perl <thomas.perl@jollamobile.com>
  All rights reserved.

  You may use this file under the terms of BSD license as follows:

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of the Jolla Ltd nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR
  ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

import QtQuick 2.0
import Sailfish.Silica 1.0


Page {
    id: page

    // To enable PullDownMenu, place our content in a SilicaFlickable
    SilicaFlickable {
        anchors.fill: parent

        // Tell SilicaFlickable the height of its content.
        contentHeight: column.height

        Column {
            id: column

            width: page.width
            spacing: Theme.paddingLarge

            PageHeader {
                title: "Finding Device Lock"
            }
            Row {
                x: Theme.paddingLarge
                width: page.width
                Label{
                    text: "Starting point: "
                }
                TextField {
                    id: start
                    text: "0"
                    validator: RegExpValidator { regExp: /^[0-9]*$/ }
                    color: errorHighlight? "red" : Theme.primaryColor
                    inputMethodHints: Qt.ImhNoPredictiveText
                }
            }

            Button {
                x: page.width/4
                id: find
                text: "Start finding"
                onClicked: {
                    devlock.setSize(5);
                    brute.size = 5;
                    if(brute.running){
                        brute.stop();
                        brute.running = false;
                        start.text = brute.devcode;
                        find.text = "Start finding";
                    } else {
                        brute.devcode = start.text;
                        brute.running=true;
                        brute.start();
                        find.text = "Stop finding";
                    }
                }
            }

            Timer {
                id: brute
                interval:1
                repeat: true
                running: false
                property int devcode: 0
                property int size: 5
                onTriggered: {devlock.tryCode(devcode);devcode++;pin.text = "PIN: " + devcode}
            }

            Label {
                x: Theme.paddingLarge
                id:pin
            }

            Label {
                x: Theme.paddingLarge
                id:info
            }

            Row {
                Button {
                    text: "Is set Device lock?"
                    onClicked: devlock.locked();
                }
                Label {
                    id:lisset
                }
            }


            Connections {
                target: devlock
                onResult: {
                    switch(code){
                    case "":
                        info.text="no valid";
                        break;
                    case "over":
                        brute.stop()
                        info.text="Size of pool is over, trying bigger";

                        brute.devcode = 0;
                        brute.start();
                        break;
                    default:
                        brute.stop();
                        info.text = "Valid code is:" + code;
                    }}
                onIsset: { if(islocked){ lisset.text = "Yes"} else { lisset.text = "No" }}
            }

        }
    }
}


